@@ -48,16 +48,13 @@
 
 #include <Python.h>
 
-/* PyObject_Del does not exist in older versions of Python: */
-#if PY_VERSION_HEX < 0x01060000
-#define PyObject_Del(op) PyMem_DEL((op))
-#endif
+#include "pgsql.h"
 
 static PyObject *Error, *Warning, *InterfaceError,
 	*DatabaseError, *InternalError, *OperationalError, *ProgrammingError,
 	*IntegrityError, *DataError, *NotSupportedError;
 
-static const char *PyPgVersion = "0.9.5";
+static const char *PyPgVersion = "0.9.6";
 static char pg__doc__[] = "Simple Python interface to PostgreSQL DB";
 
 /* default values */
@@ -545,7 +542,7 @@ static pgparams *_pgsource_getparams(PyObject *params)
 		ret->paramTypes[i] = INT8OID;
 	    Py_DECREF(str);
 	} else if (PyString_Check(param)) {
-	    int len;
+	    Py_ssize_t len;
 	    PyString_AsStringAndSize(param, &(ret->paramValues[i]), &len);
 	    if (memchr(ret->paramValues[i], '\0', len)) {
 		ret->paramTypes[i] = BYTEAOID;
@@ -555,7 +552,7 @@ static pgparams *_pgsource_getparams(PyObject *params)
 	    }
 	    ret->paramLengths[i] = len;
 	} else if (PyUnicode_Check(param)) {
-	    int len;
+	    Py_ssize_t len;
 	    len = PyUnicode_GET_DATA_SIZE(param);
 	    ret->paramValues[i] = (char *) PyUnicode_AS_DATA(param);
 	    ret->paramTypes[i] = VARCHAROID;
@@ -580,7 +577,7 @@ static pgparams *_pgsource_getparams(PyObject *params)
 	} else { /* this is an object that hopefully we can str() */
 	    PyObject *o = NULL;
 	    PyObject *str = NULL;
-	    int len;
+	    Py_ssize_t len;
 	    char *value;
 
 	    /* is this an object that needs to be treated as a binary one? */
@@ -997,7 +994,7 @@ _pg_fetch_cell(PGresult *result, int row, int col)
 		char *newStr;
 		size_t newLen;
 		newStr = PQunescapeBytea(cell, &newLen);
-		ret = PyString_FromStringAndSize(newStr, newLen);
+		ret = PyString_FromStringAndSize(newStr, (Py_ssize_t)newLen);
 		PQfreemem(newStr);
 		break;
 	    }
@@ -1005,7 +1002,7 @@ _pg_fetch_cell(PGresult *result, int row, int col)
 	default:
 	    {
 		void *tmpstr = NULL;
-		int tmplen = 0;
+		Py_ssize_t tmplen = 0;
 		int retcode = 0;
 		fprintf(stderr, "WARNING: Unknown datatype %d processed as string. "
 			"Check pg_type.h to decode this OID\n", oidtype);
