@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# pgsql.py version 0.9.5
+# pgsql.py version 0.9.6
 #
 # Updated by Cristian Gafton to use the bind parameters
 # and adapt to the new interface provided by the C bindings
@@ -54,7 +54,7 @@ import weakref
 __CONNLIST = []
 
 ### module constants
-version = "0.9.5"
+version = "0.9.6"
 
 # compliant with DB SIG 2.0
 apilevel = '2.0'
@@ -92,9 +92,6 @@ class Cursor(object):
     def close(self):
         self._source.close()
 
-    def arraysize(self, size):
-        self.arraysize = size
-
     def _start(self, operation = None):
         transaction = self.transaction
         if transaction == TRANS_UNKNOWN:
@@ -135,10 +132,16 @@ class Cursor(object):
     def fetchall(self):
         return self._source.fetchall()
 
+    def __manyiter(self, size, fetchone):
+        for x in xrange(size):
+            val = fetchone()
+            if val is None:
+                raise StopIteration
+            yield val
     def fetchmany(self, size = None):
-        if size == None:
+        if size is None:
             size = self.arraysize
-        return [self._source.fetchone() for x in range(size)]
+        return list(self.__manyiter(size, self._source.fetchone))
 
     # extensions
     def fetchone_dict(self):
@@ -148,7 +151,7 @@ class Cursor(object):
     def fetchmany_dict(self, size = None):
         if size == None:
             size = self.arraysize
-        return [self._source.fetchonedict() for x in range(size)]
+        return list(self.__manyiter(size, self._source.fetchonedict))
 
     def nextset(self):
         raise NotSupportedError, "nextset() is not supported"
